==> libgtop-1.1.4.tar.gz: libgtop-1.1.4/lib/structures.h <==
/* structures.h */
/* This is a generated file.  Please modify `guile.pl' */

#ifndef __GLIBTOP_STRUCTURES_H__
#define __GLIBTOP_STRUCTURES_H__

#include <glibtop.h>

BEGIN_LIBGTOP_DECLS

#define GLIBTOP_STRUCTURE_GLIBTOP               	0
#define GLIBTOP_STRUCTURE_GLIBTOP_CPU           	1
#define GLIBTOP_STRUCTURE_GLIBTOP_MEM           	2
#define GLIBTOP_STRUCTURE_GLIBTOP_SWAP          	3
#define GLIBTOP_STRUCTURE_GLIBTOP_UPTIME        	4
#define GLIBTOP_STRUCTURE_GLIBTOP_LOADAVG       	5
#define GLIBTOP_STRUCTURE_GLIBTOP_SHM_LIMITS    	6
#define GLIBTOP_STRUCTURE_GLIBTOP_MSG_LIMITS    	7
#define GLIBTOP_STRUCTURE_GLIBTOP_SEM_LIMITS    	8
#define GLIBTOP_STRUCTURE_GLIBTOP_PROCLIST      	9
#define GLIBTOP_STRUCTURE_GLIBTOP_PROC_STATE    	10
#define GLIBTOP_STRUCTURE_GLIBTOP_PROC_UID      	11
#define GLIBTOP_STRUCTURE_GLIBTOP_PROC_MEM      	12
#define GLIBTOP_STRUCTURE_GLIBTOP_PROC_TIME     	13
#define GLIBTOP_STRUCTURE_GLIBTOP_PROC_SIGNAL   	14
#define GLIBTOP_STRUCTURE_GLIBTOP_PROC_KERNEL   	15
#define GLIBTOP_STRUCTURE_GLIBTOP_PROC_SEGMENT  	16
#define GLIBTOP_STRUCTURE_GLIBTOP_PROC_ARGS     	17
#define GLIBTOP_STRUCTURE_GLIBTOP_PROC_MAP      	18
#define GLIBTOP_STRUCTURE_GLIBTOP_MOUNTLIST     	19
#define GLIBTOP_STRUCTURE_GLIBTOP_FSUSAGE       	20
#define GLIBTOP_STRUCTURE_GLIBTOP_INTERFACE_NAMES	21
#define GLIBTOP_STRUCTURE_GLIBTOP_NETINFO       	22
#define GLIBTOP_STRUCTURE_GLIBTOP_NETLOAD       	23
#define GLIBTOP_STRUCTURE_GLIBTOP_PPP           	24
#define GLIBTOP_STRUCTURE_GLIBTOP_MAP_ENTRY     	25
#define GLIBTOP_STRUCTURE_GLIBTOP_MOUNTENTRY    	26
#define GLIBTOP_STRUCTURE_GLIBTOP_INTERFACE     	27
#define GLIBTOP_STRUCTURE_GLIBTOP_SYSDEPS       	28

#define GLIBTOP_MAX_STRUCTURES                  	29

END_LIBGTOP_DECLS

#endif /* __GLIBTOP_STRUCTURES_H__ */

==> libgtop-1.1.5.tar.gz: libgtop-1.1.5/lib/structures.h <==
/* structures.h */
/* This is a generated file.  Please modify `guile.pl' */

#ifndef __GLIBTOP_STRUCTURES_H__
#define __GLIBTOP_STRUCTURES_H__

#include <glibtop.h>

BEGIN_LIBGTOP_DECLS

#define GLIBTOP_STRUCTURE_GLIBTOP               	0
#define GLIBTOP_STRUCTURE_GLIBTOP_CPU           	1
#define GLIBTOP_STRUCTURE_GLIBTOP_MEM           	2
#define GLIBTOP_STRUCTURE_GLIBTOP_SWAP          	3
#define GLIBTOP_STRUCTURE_GLIBTOP_UPTIME        	4
#define GLIBTOP_STRUCTURE_GLIBTOP_LOADAVG       	5
#define GLIBTOP_STRUCTURE_GLIBTOP_SHM_LIMITS    	6
#define GLIBTOP_STRUCTURE_GLIBTOP_MSG_LIMITS    	7
#define GLIBTOP_STRUCTURE_GLIBTOP_SEM_LIMITS    	8
#define GLIBTOP_STRUCTURE_GLIBTOP_PROCLIST      	9
#define GLIBTOP_STRUCTURE_GLIBTOP_PROC_STATE    	10
#define GLIBTOP_STRUCTURE_GLIBTOP_PROC_UID      	11
#define GLIBTOP_STRUCTURE_GLIBTOP_PROC_MEM      	12
#define GLIBTOP_STRUCTURE_GLIBTOP_PROC_TIME     	13
#define GLIBTOP_STRUCTURE_GLIBTOP_PROC_SIGNAL   	14
#define GLIBTOP_STRUCTURE_GLIBTOP_PROC_KERNEL   	15
#define GLIBTOP_STRUCTURE_GLIBTOP_PROC_SEGMENT  	16
#define GLIBTOP_STRUCTURE_GLIBTOP_PROC_ARGS     	17
#define GLIBTOP_STRUCTURE_GLIBTOP_PROC_MAP      	18
#define GLIBTOP_STRUCTURE_GLIBTOP_MOUNTLIST     	19
#define GLIBTOP_STRUCTURE_GLIBTOP_FSUSAGE       	20
#define GLIBTOP_STRUCTURE_GLIBTOP_INTERFACE_NAMES	21
#define GLIBTOP_STRUCTURE_GLIBTOP_NETINFO       	22
#define GLIBTOP_STRUCTURE_GLIBTOP_NETLOAD       	23
#define GLIBTOP_STRUCTURE_GLIBTOP_PPP           	24
#define GLIBTOP_STRUCTURE_GLIBTOP_MAP_ENTRY     	25
#define GLIBTOP_STRUCTURE_GLIBTOP_MOUNTENTRY    	26
#define GLIBTOP_STRUCTURE_GLIBTOP_INTERFACE     	27
#define GLIBTOP_STRUCTURE_GLIBTOP_SYSDEPS       	28
#define GLIBTOP_STRUCTURE_GLIBTOP_IFADDR        	29

#define GLIBTOP_MAX_STRUCTURES                  	30

END_LIBGTOP_DECLS

#endif /* __GLIBTOP_STRUCTURES_H__ */
